@@ -5,9 +5,12 @@ workflows of AiiDA-KKR
 # import all workflows here to expose them in `aiida_kkr.workflows` directly
 from .voro_start import kkr_startpot_wc
 from .dos import kkr_dos_wc, parse_dosfiles
+from .bs import kkr_bs_wc, parse_BS_data
 from .kkr_scf import kkr_scf_wc
 from .eos import kkr_eos_wc, rescale, get_primitive_structure
 from .gf_writeout import kkr_flex_wc
 from .kkr_imp_sub import kkr_imp_sub_wc
 from .kkr_imp import kkr_imp_wc
 from .kkr_imp_dos import kkr_imp_dos_wc
+from ._combine_imps import combine_imps_wc
+from ._decimation import kkr_decimation_wc
